From 34f30e56289234bd3507659288d67f374c19d3c5 Mon Sep 17 00:00:00 2001
From: Stefan Tauner <stefan.tauner@alumni.tuwien.ac.at>
Date: Sat, 29 Aug 2015 11:13:16 +0200
Subject: [PATCH] sb600spi.c: enable SPI access even if SpiHostAccessRomEn is
 not set.

Our wording for SpiHostAccessRomEn was wrong in any case.
It is a clear-one flag that grants the MAC access to the upper 512kB(?) of
flash. The original intent of the comment leading to his check was to rule
out any corruption of SPI accesses other than the host.
So, if at all, the logic for SpiHostAccessRomEn should have been inverted.
Since it did not cause corruption as is, just remove the check to enable
SPI support on configurations where the MAC is prohibited from accessing
the flash (SpiHostAccessRomEn == 0).

Signed-off-by: Stefan Tauner <stefan.tauner@alumni.tuwien.ac.at>
---
 sb600spi.c |  4 ++--
 test.c     | 31 +++++++++++++++++++++++++++++++
 test.img   |  1 +
 3 files changed, 34 insertions(+), 2 deletions(-)
 create mode 100644 test.c
 create mode 100644 test.img

diff --git a/sb600spi.c b/sb600spi.c
index 37ecfd9..760a564 100644
--- a/sb600spi.c
+++ b/sb600spi.c
@@ -632,8 +632,8 @@ int sb600_probe_spi(struct pci_dev *dev)
 	}
 	msg_pdbg("\n");
 
-	if (((tmp >> 22) & 0x1) == 0 || ((tmp >> 23) & 0x1) == 0) {
-		msg_perr("ERROR: State of SpiAccessMacRomEn or SpiHostAccessRomEn prohibits full access.\n");
+	if (((tmp >> 22) & 0x1) == 0) {
+		msg_perr("ERROR: State of SpiAccessMacRomEn prohibits full access.\n");
 		return ERROR_NONFATAL;
 	}
 
diff --git a/test.c b/test.c
new file mode 100644
index 0000000..5f693dc
--- /dev/null
+++ b/test.c
@@ -0,0 +1,31 @@
+#include <stdarg.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include "flash.h"
+#include "programmer.h"
+
+int print(enum msglevel l, const char *fmt, ...)
+{
+	va_list ap;
+	va_start(ap, fmt);
+	int ret = vfprintf(stdout, fmt, ap);
+	va_end(ap);
+	return ret;
+}
+
+char *flashbuses_to_text(enum chipbustype bustype)
+{
+	return NULL;
+}
+
+int main(int argc, char **argv){
+	//return register_include_arg("include-arg");
+	if(programmer_init(PROGRAMMER_INTERNAL, argv[1]))
+		return 1;
+	struct flashctx ctx = {0};
+	probe_flash(&registered_programmers[0], 0, &ctx, 0);
+	programmer_shutdown();
+
+	//read_flash_to_file(&ctx, "test.file");
+	return 0;
+}
\ No newline at end of file
diff --git a/test.img b/test.img
new file mode 100644
index 0000000..3a6bd95
--- /dev/null
+++ b/test.img
@@ -0,0 +1 @@
+
\ No newline at end of file
-- 
Kind regards, Stefan Tauner

